==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        bi() {
            return new ForceIndexIndicator();
        }
        get_aat() {
            return 1;
        }
        constructor() {
            super();
        }
        get_abm() {
            return new ForceIndexIndicatorStrategy();
        }
        get abm() {
            return this.get_abm();
        }
        get_abz() {
            return ForceIndexIndicator.$;
        }
        get abz() {
            return this.get_abz();
        }
        get ab7() {
            return typeGetValue(this.c(ForceIndexIndicator.ab8));
        }
        set ab7(a) {
            this.h(ForceIndexIndicator.ab8, a);
        }
        abs() {
            return this.ab7;
        }
        ab1(a) {
            this.ab7 = a;
        }
    }
    ForceIndexIndicator.$t = /*@__PURE__*/ markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.ab8 = /*@__PURE__*/ StrategyBasedIndicator.ab4(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm2015/lib/ForceIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ForceIndexIndicatorStrategy } from "./ForceIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let ForceIndexIndicator = /*@__PURE__*/ (() => {
    class ForceIndexIndicator extends StrategyBasedIndicator {
        bj() {
            return new ForceIndexIndicator();
        }
        get_aa2() {
            return 1;
        }
        constructor() {
            super();
        }
        get_abv() {
            return new ForceIndexIndicatorStrategy();
        }
        get abv() {
            return this.get_abv();
        }
        get_ab8() {
            return ForceIndexIndicator.$;
        }
        get ab8() {
            return this.get_ab8();
        }
        get acg() {
            return typeGetValue(this.c(ForceIndexIndicator.ach));
        }
        set acg(a) {
            this.h(ForceIndexIndicator.ach, a);
        }
        ab1() {
            return this.acg;
        }
        aca(a) {
            this.acg = a;
        }
    }
    ForceIndexIndicator.$t = /*@__PURE__*/ markType(ForceIndexIndicator, 'ForceIndexIndicator', StrategyBasedIndicator.$);
    ForceIndexIndicator.ach = /*@__PURE__*/ StrategyBasedIndicator.acd(0, ForceIndexIndicator.$);
    return ForceIndexIndicator;
})();
